@@ -34,9 +34,9 @@
 #include <log4cxx/private/log4cxx_private.h>
 #include <log4cxx/helpers/aprinitializer.h>
 
-using namespace log4cxx;
-using namespace log4cxx::helpers;
-using namespace log4cxx::spi;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::helpers;
+using namespace LOG4CXX_NS::spi;
 
 struct Logger::LoggerPrivate
 {
@@ -70,7 +70,7 @@ struct Logger::LoggerPrivate
 
 
 	// Loggers need to know what Hierarchy they are in
-	log4cxx::spi::LoggerRepository* repositoryRaw;
+	LOG4CXX_NS::spi::LoggerRepository* repositoryRaw;
 
 	helpers::AppenderAttachableImpl aai;
 
@@ -158,27 +158,46 @@ void Logger::closeNestedAppenders()
 	}
 }
 
+void Logger::addEvent(const LevelPtr& level, std::string&& message, const LocationInfo& location) const
+{
+	if (!getHierarchy()) // Has removeHierarchy() been called?
+		return;
+#if LOG4CXX_LOGCHAR_IS_UTF8
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, location, std::move(message));
+#else
+	LOG4CXX_DECODE_CHAR(msg, message);
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, location, std::move(msg));
+#endif
+	Pool p;
+	callAppenders(event, p);
+}
 
-void Logger::forcedLog(const LevelPtr& level1, const std::string& message,
+void Logger::forcedLog(const LevelPtr& level, const std::string& message,
 	const LocationInfo& location) const
 {
 	if (!getHierarchy()) // Has removeHierarchy() been called?
 		return;
-	Pool p;
+#if LOG4CXX_LOGCHAR_IS_UTF8
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, message, location);
+#else
 	LOG4CXX_DECODE_CHAR(msg, message);
-	auto event = std::make_shared<LoggingEvent>(m_priv->name, level1, msg, location);
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, location, std::move(msg));
+#endif
+	Pool p;
 	callAppenders(event, p);
 }
 
-
 void Logger::forcedLog(const LevelPtr& level1, const std::string& message) const
+{
+	forcedLog(level1, message, LocationInfo::getLocationUnavailable());
+}
+
+void Logger::addEventLS(const LevelPtr& level, LogString&& message, const LocationInfo& location) const
 {
 	if (!getHierarchy()) // Has removeHierarchy() been called?
 		return;
 	Pool p;
-	LOG4CXX_DECODE_CHAR(msg, message);
-	auto event = std::make_shared<LoggingEvent>(m_priv->name, level1, msg,
-			LocationInfo::getLocationUnavailable());
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, location, std::move(message));
 	callAppenders(event, p);
 }
 
@@ -427,7 +446,7 @@ void Logger::l7dlog(const LevelPtr& level1, const LogString& key,
 			msg = StringHelper::format(pattern, params);
 		}
 
-		forcedLogLS(level1, msg, location);
+		addEventLS(level1, std::move(msg), location);
 	}
 }
 
@@ -483,17 +502,32 @@ void Logger::l7dlog(const LevelPtr& level1, const std::string& key,
 
 void Logger::removeAllAppenders()
 {
+	AppenderList currentAppenders = m_priv->aai.getAllAppenders();
 	m_priv->aai.removeAllAppenders();
+
+	auto rep = getHierarchy();
+	if(rep){
+		for(AppenderPtr appender : currentAppenders){
+			rep->fireRemoveAppenderEvent(this, appender.get());
+		}
+	}
 }
 
 void Logger::removeAppender(const AppenderPtr appender)
 {
 	m_priv->aai.removeAppender(appender);
+	if (auto rep = getHierarchy())
+	{
+		rep->fireRemoveAppenderEvent(this, appender.get());
+	}
 }
 
 void Logger::removeAppender(const LogString& name1)
 {
-	m_priv->aai.removeAppender(name1);
+	AppenderPtr appender = m_priv->aai.getAppender(name1);
+	if(appender){
+		removeAppender(appender);
+	}
 }
 
 void Logger::removeHierarchy()
@@ -519,10 +553,13 @@ void Logger::setParent(LoggerPtr parentLogger)
 
 void Logger::setLevel(const LevelPtr level1)
 {
-	m_priv->level = level1;
-	updateThreshold();
-	if (auto rep = dynamic_cast<Hierarchy*>(getHierarchy()))
-		rep->updateChildren(this);
+	if (m_priv->level != level1)
+	{
+		m_priv->level = level1;
+		updateThreshold();
+		if (auto rep = dynamic_cast<Hierarchy*>(getHierarchy()))
+			rep->updateChildren(this);
+	}
 }
 
 void Logger::updateThreshold()
@@ -568,11 +605,11 @@ void Logger::getName(std::string& rv) const
 }
 
 
-void Logger::trace(const std::string& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::trace(const std::string& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isTraceEnabled())
 	{
-		forcedLog(log4cxx::Level::getTrace(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getTrace(), msg, location);
 	}
 }
 
@@ -581,15 +618,15 @@ void Logger::trace(const std::string& msg) const
 {
 	if (isTraceEnabled())
 	{
-		forcedLog(log4cxx::Level::getTrace(), msg);
+		forcedLog(LOG4CXX_NS::Level::getTrace(), msg);
 	}
 }
 
-void Logger::debug(const std::string& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::debug(const std::string& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isDebugEnabled())
 	{
-		forcedLog(log4cxx::Level::getDebug(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getDebug(), msg, location);
 	}
 }
 
@@ -597,16 +634,16 @@ void Logger::debug(const std::string& msg) const
 {
 	if (isDebugEnabled())
 	{
-		forcedLog(log4cxx::Level::getDebug(), msg);
+		forcedLog(LOG4CXX_NS::Level::getDebug(), msg);
 	}
 }
 
 
-void Logger::error(const std::string& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::error(const std::string& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isErrorEnabled())
 	{
-		forcedLog(log4cxx::Level::getError(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getError(), msg, location);
 	}
 }
 
@@ -615,15 +652,15 @@ void Logger::error(const std::string& msg) const
 {
 	if (isErrorEnabled())
 	{
-		forcedLog(log4cxx::Level::getError(), msg);
+		forcedLog(LOG4CXX_NS::Level::getError(), msg);
 	}
 }
 
-void Logger::fatal(const std::string& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::fatal(const std::string& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isFatalEnabled())
 	{
-		forcedLog(log4cxx::Level::getFatal(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getFatal(), msg, location);
 	}
 }
 
@@ -631,15 +668,15 @@ void Logger::fatal(const std::string& msg) const
 {
 	if (isFatalEnabled())
 	{
-		forcedLog(log4cxx::Level::getFatal(), msg);
+		forcedLog(LOG4CXX_NS::Level::getFatal(), msg);
 	}
 }
 
-void Logger::info(const std::string& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::info(const std::string& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isInfoEnabled())
 	{
-		forcedLog(log4cxx::Level::getInfo(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getInfo(), msg, location);
 	}
 }
 
@@ -647,12 +684,12 @@ void Logger::info(const std::string& msg) const
 {
 	if (isInfoEnabled())
 	{
-		forcedLog(log4cxx::Level::getInfo(), msg);
+		forcedLog(LOG4CXX_NS::Level::getInfo(), msg);
 	}
 }
 
 void Logger::log(const LevelPtr& level1, const std::string& message,
-	const log4cxx::spi::LocationInfo& location) const
+	const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isEnabledFor(level1))
 	{
@@ -669,7 +706,7 @@ void Logger::log(const LevelPtr& level1, const std::string& message) const
 }
 
 void Logger::logLS(const LevelPtr& level1, const LogString& message,
-	const log4cxx::spi::LocationInfo& location) const
+	const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isEnabledFor(level1))
 	{
@@ -677,11 +714,11 @@ void Logger::logLS(const LevelPtr& level1, const LogString& message,
 	}
 }
 
-void Logger::warn(const std::string& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::warn(const std::string& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isWarnEnabled())
 	{
-		forcedLog(log4cxx::Level::getWarn(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getWarn(), msg, location);
 	}
 }
 
@@ -689,7 +726,7 @@ void Logger::warn(const std::string& msg) const
 {
 	if (isWarnEnabled())
 	{
-		forcedLog(log4cxx::Level::getWarn(), msg);
+		forcedLog(LOG4CXX_NS::Level::getWarn(), msg);
 	}
 }
 
@@ -702,26 +739,38 @@ LoggerPtr Logger::getLoggerLS(const LogString& name)
 
 
 #if LOG4CXX_WCHAR_T_API
-void Logger::forcedLog(const LevelPtr& level1, const std::wstring& message,
+void Logger::addEvent(const LevelPtr& level, std::wstring&& message, const LocationInfo& location) const
+{
+	if (!getHierarchy()) // Has removeHierarchy() been called?
+		return;
+#if LOG4CXX_LOGCHAR_IS_WCHAR
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, location, std::move(message));
+#else
+	LOG4CXX_DECODE_WCHAR(msg, message);
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, location, std::move(msg));
+#endif
+	Pool p;
+	callAppenders(event, p);
+}
+
+void Logger::forcedLog(const LevelPtr& level, const std::wstring& message,
 	const LocationInfo& location) const
 {
 	if (!getHierarchy()) // Has removeHierarchy() been called?
 		return;
-	Pool p;
+#if LOG4CXX_LOGCHAR_IS_WCHAR
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, message, location);
+#else
 	LOG4CXX_DECODE_WCHAR(msg, message);
-	auto event = std::make_shared<LoggingEvent>(m_priv->name, level1, msg, location);
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, location, std::move(msg));
+#endif
+	Pool p;
 	callAppenders(event, p);
 }
 
 void Logger::forcedLog(const LevelPtr& level1, const std::wstring& message) const
 {
-	if (!getHierarchy()) // Has removeHierarchy() been called?
-		return;
-	Pool p;
-	LOG4CXX_DECODE_WCHAR(msg, message);
-	auto event = std::make_shared<LoggingEvent>(m_priv->name, level1, msg,
-			LocationInfo::getLocationUnavailable());
-	callAppenders(event, p);
+	forcedLog(level1, message, LocationInfo::getLocationUnavailable());
 }
 
 void Logger::getName(std::wstring& rv) const
@@ -739,11 +788,11 @@ LoggerPtr Logger::getLogger(const wchar_t* const name)
 	return LogManager::getLogger(name);
 }
 
-void Logger::trace(const std::wstring& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::trace(const std::wstring& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isTraceEnabled())
 	{
-		forcedLog(log4cxx::Level::getTrace(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getTrace(), msg, location);
 	}
 }
 
@@ -752,15 +801,15 @@ void Logger::trace(const std::wstring& msg) const
 {
 	if (isTraceEnabled())
 	{
-		forcedLog(log4cxx::Level::getTrace(), msg);
+		forcedLog(LOG4CXX_NS::Level::getTrace(), msg);
 	}
 }
 
-void Logger::debug(const std::wstring& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::debug(const std::wstring& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isDebugEnabled())
 	{
-		forcedLog(log4cxx::Level::getDebug(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getDebug(), msg, location);
 	}
 }
 
@@ -768,15 +817,15 @@ void Logger::debug(const std::wstring& msg) const
 {
 	if (isDebugEnabled())
 	{
-		forcedLog(log4cxx::Level::getDebug(), msg);
+		forcedLog(LOG4CXX_NS::Level::getDebug(), msg);
 	}
 }
 
-void Logger::error(const std::wstring& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::error(const std::wstring& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isErrorEnabled())
 	{
-		forcedLog(log4cxx::Level::getError(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getError(), msg, location);
 	}
 }
 
@@ -784,15 +833,15 @@ void Logger::error(const std::wstring& msg) const
 {
 	if (isErrorEnabled())
 	{
-		forcedLog(log4cxx::Level::getError(), msg);
+		forcedLog(LOG4CXX_NS::Level::getError(), msg);
 	}
 }
 
-void Logger::fatal(const std::wstring& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::fatal(const std::wstring& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isFatalEnabled())
 	{
-		forcedLog(log4cxx::Level::getFatal(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getFatal(), msg, location);
 	}
 }
 
@@ -800,15 +849,15 @@ void Logger::fatal(const std::wstring& msg) const
 {
 	if (isFatalEnabled())
 	{
-		forcedLog(log4cxx::Level::getFatal(), msg);
+		forcedLog(LOG4CXX_NS::Level::getFatal(), msg);
 	}
 }
 
-void Logger::info(const std::wstring& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::info(const std::wstring& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isInfoEnabled())
 	{
-		forcedLog(log4cxx::Level::getInfo(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getInfo(), msg, location);
 	}
 }
 
@@ -816,12 +865,12 @@ void Logger::info(const std::wstring& msg) const
 {
 	if (isInfoEnabled())
 	{
-		forcedLog(log4cxx::Level::getInfo(), msg);
+		forcedLog(LOG4CXX_NS::Level::getInfo(), msg);
 	}
 }
 
 void Logger::log(const LevelPtr& level1, const std::wstring& message,
-	const log4cxx::spi::LocationInfo& location) const
+	const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isEnabledFor(level1))
 	{
@@ -837,11 +886,11 @@ void Logger::log(const LevelPtr& level1, const std::wstring& message) const
 	}
 }
 
-void Logger::warn(const std::wstring& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::warn(const std::wstring& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isWarnEnabled())
 	{
-		forcedLog(log4cxx::Level::getWarn(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getWarn(), msg, location);
 	}
 }
 
@@ -849,14 +898,24 @@ void Logger::warn(const std::wstring& msg) const
 {
 	if (isWarnEnabled())
 	{
-		forcedLog(log4cxx::Level::getWarn(), msg);
+		forcedLog(LOG4CXX_NS::Level::getWarn(), msg);
 	}
 }
 
 #endif
 
 
-#if LOG4CXX_UNICHAR_API || LOG4CXX_CFSTRING_API
+#if LOG4CXX_UNICHAR_API
+void Logger::addEvent(const LevelPtr& level1, std::basic_string<UniChar>&& message,	const LocationInfo& location) const
+{
+	if (!getHierarchy()) // Has removeHierarchy() been called?
+		return;
+	Pool p;
+	LOG4CXX_DECODE_UNICHAR(msg, message);
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level1, location, std::move(msg));
+	callAppenders(event, p);
+}
+
 void Logger::forcedLog(const LevelPtr& level1, const std::basic_string<UniChar>& message,
 	const LocationInfo& location) const
 {
@@ -864,7 +923,7 @@ void Logger::forcedLog(const LevelPtr& level1, const std::basic_string<UniChar>&
 		return;
 	Pool p;
 	LOG4CXX_DECODE_UNICHAR(msg, message);
-	auto event = std::make_shared<LoggingEvent>(m_priv->name, level1, msg, location);
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level1, location, std::move(msg));
 	callAppenders(event, p);
 }
 
@@ -878,9 +937,7 @@ void Logger::forcedLog(const LevelPtr& level1, const std::basic_string<UniChar>&
 			LocationInfo::getLocationUnavailable());
 	callAppenders(event, p);
 }
-#endif
 
-#if LOG4CXX_UNICHAR_API
 void Logger::getName(std::basic_string<UniChar>& rv) const
 {
 	Transcoder::encode(m_priv->name, rv);
@@ -891,11 +948,11 @@ LoggerPtr Logger::getLogger(const std::basic_string<UniChar>& name)
 	return LogManager::getLogger(name);
 }
 
-void Logger::trace(const std::basic_string<UniChar>& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::trace(const std::basic_string<UniChar>& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isTraceEnabled())
 	{
-		forcedLog(log4cxx::Level::getTrace(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getTrace(), msg, location);
 	}
 }
 
@@ -904,15 +961,15 @@ void Logger::trace(const std::basic_string<UniChar>& msg) const
 {
 	if (isTraceEnabled())
 	{
-		forcedLog(log4cxx::Level::getTrace(), msg);
+		forcedLog(LOG4CXX_NS::Level::getTrace(), msg);
 	}
 }
 
-void Logger::debug(const std::basic_string<UniChar>& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::debug(const std::basic_string<UniChar>& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isDebugEnabled())
 	{
-		forcedLog(log4cxx::Level::getDebug(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getDebug(), msg, location);
 	}
 }
 
@@ -920,15 +977,15 @@ void Logger::debug(const std::basic_string<UniChar>& msg) const
 {
 	if (isDebugEnabled())
 	{
-		forcedLog(log4cxx::Level::getDebug(), msg);
+		forcedLog(LOG4CXX_NS::Level::getDebug(), msg);
 	}
 }
 
-void Logger::error(const std::basic_string<UniChar>& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::error(const std::basic_string<UniChar>& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isErrorEnabled())
 	{
-		forcedLog(log4cxx::Level::getError(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getError(), msg, location);
 	}
 }
 
@@ -936,15 +993,15 @@ void Logger::error(const std::basic_string<UniChar>& msg) const
 {
 	if (isErrorEnabled())
 	{
-		forcedLog(log4cxx::Level::getError(), msg);
+		forcedLog(LOG4CXX_NS::Level::getError(), msg);
 	}
 }
 
-void Logger::fatal(const std::basic_string<UniChar>& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::fatal(const std::basic_string<UniChar>& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isFatalEnabled())
 	{
-		forcedLog(log4cxx::Level::getFatal(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getFatal(), msg, location);
 	}
 }
 
@@ -952,15 +1009,15 @@ void Logger::fatal(const std::basic_string<UniChar>& msg) const
 {
 	if (isFatalEnabled())
 	{
-		forcedLog(log4cxx::Level::getFatal(), msg);
+		forcedLog(LOG4CXX_NS::Level::getFatal(), msg);
 	}
 }
 
-void Logger::info(const std::basic_string<UniChar>& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::info(const std::basic_string<UniChar>& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isInfoEnabled())
 	{
-		forcedLog(log4cxx::Level::getInfo(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getInfo(), msg, location);
 	}
 }
 
@@ -968,12 +1025,12 @@ void Logger::info(const std::basic_string<UniChar>& msg) const
 {
 	if (isInfoEnabled())
 	{
-		forcedLog(log4cxx::Level::getInfo(), msg);
+		forcedLog(LOG4CXX_NS::Level::getInfo(), msg);
 	}
 }
 
 void Logger::log(const LevelPtr& level1, const std::basic_string<UniChar>& message,
-	const log4cxx::spi::LocationInfo& location) const
+	const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isEnabledFor(level1))
 	{
@@ -989,11 +1046,11 @@ void Logger::log(const LevelPtr& level1, const std::basic_string<UniChar>& messa
 	}
 }
 
-void Logger::warn(const std::basic_string<UniChar>& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::warn(const std::basic_string<UniChar>& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isWarnEnabled())
 	{
-		forcedLog(log4cxx::Level::getWarn(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getWarn(), msg, location);
 	}
 }
 
@@ -1001,7 +1058,7 @@ void Logger::warn(const std::basic_string<UniChar>& msg) const
 {
 	if (isWarnEnabled())
 	{
-		forcedLog(log4cxx::Level::getWarn(), msg);
+		forcedLog(LOG4CXX_NS::Level::getWarn(), msg);
 	}
 }
 
@@ -1009,31 +1066,31 @@ void Logger::warn(const std::basic_string<UniChar>& msg) const
 
 
 #if LOG4CXX_CFSTRING_API
-void Logger::forcedLog(const LevelPtr& level1, const CFStringRef& message,
+void Logger::forcedLog(const LevelPtr& level, const CFStringRef& message,
 	const LocationInfo& location) const
 {
 	if (!getHierarchy()) // Has removeHierarchy() been called?
 		return;
 	Pool p;
 	LOG4CXX_DECODE_CFSTRING(msg, message);
-	auto event = std::make_shared<LoggingEvent>(name, level1, msg, location);
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, location, std::move(msg));
 	callAppenders(event, p);
 }
 
-void Logger::forcedLog(const LevelPtr& level1, const CFStringRef& message) const
+void Logger::forcedLog(const LevelPtr& level, const CFStringRef& message) const
 {
 	if (!getHierarchy()) // Has removeHierarchy() been called?
 		return;
 	Pool p;
 	LOG4CXX_DECODE_CFSTRING(msg, message);
-	auto event = std::make_shared<LoggingEvent>(name, level1, msg,
+	auto event = std::make_shared<LoggingEvent>(m_priv->name, level, msg,
 			LocationInfo::getLocationUnavailable());
 	callAppenders(event, p);
 }
 
 void Logger::getName(CFStringRef& rv) const
 {
-	rv = Transcoder::encode(name);
+	rv = Transcoder::encode(m_priv->name);
 }
 
 LoggerPtr Logger::getLogger(const CFStringRef& name)
@@ -1041,11 +1098,11 @@ LoggerPtr Logger::getLogger(const CFStringRef& name)
 	return LogManager::getLogger(name);
 }
 
-void Logger::trace(const CFStringRef& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::trace(const CFStringRef& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isTraceEnabled())
 	{
-		forcedLog(log4cxx::Level::getTrace(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getTrace(), msg, location);
 	}
 }
 
@@ -1054,15 +1111,15 @@ void Logger::trace(const CFStringRef& msg) const
 {
 	if (isTraceEnabled())
 	{
-		forcedLog(log4cxx::Level::getTrace(), msg);
+		forcedLog(LOG4CXX_NS::Level::getTrace(), msg);
 	}
 }
 
-void Logger::debug(const CFStringRef& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::debug(const CFStringRef& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isDebugEnabled())
 	{
-		forcedLog(log4cxx::Level::getDebug(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getDebug(), msg, location);
 	}
 }
 
@@ -1070,15 +1127,15 @@ void Logger::debug(const CFStringRef& msg) const
 {
 	if (isDebugEnabled())
 	{
-		forcedLog(log4cxx::Level::getDebug(), msg);
+		forcedLog(LOG4CXX_NS::Level::getDebug(), msg);
 	}
 }
 
-void Logger::error(const CFStringRef& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::error(const CFStringRef& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isErrorEnabled())
 	{
-		forcedLog(log4cxx::Level::getError(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getError(), msg, location);
 	}
 }
 
@@ -1086,15 +1143,15 @@ void Logger::error(const CFStringRef& msg) const
 {
 	if (isErrorEnabled())
 	{
-		forcedLog(log4cxx::Level::getError(), msg);
+		forcedLog(LOG4CXX_NS::Level::getError(), msg);
 	}
 }
 
-void Logger::fatal(const CFStringRef& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::fatal(const CFStringRef& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isFatalEnabled())
 	{
-		forcedLog(log4cxx::Level::getFatal(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getFatal(), msg, location);
 	}
 }
 
@@ -1102,15 +1159,15 @@ void Logger::fatal(const CFStringRef& msg) const
 {
 	if (isFatalEnabled())
 	{
-		forcedLog(log4cxx::Level::getFatal(), msg);
+		forcedLog(LOG4CXX_NS::Level::getFatal(), msg);
 	}
 }
 
-void Logger::info(const CFStringRef& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::info(const CFStringRef& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isInfoEnabled())
 	{
-		forcedLog(log4cxx::Level::getInfo(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getInfo(), msg, location);
 	}
 }
 
@@ -1118,12 +1175,12 @@ void Logger::info(const CFStringRef& msg) const
 {
 	if (isInfoEnabled())
 	{
-		forcedLog(log4cxx::Level::getInfo(), msg);
+		forcedLog(LOG4CXX_NS::Level::getInfo(), msg);
 	}
 }
 
 void Logger::log(const LevelPtr& level1, const CFStringRef& message,
-	const log4cxx::spi::LocationInfo& location) const
+	const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isEnabledFor(level1))
 	{
@@ -1139,11 +1196,11 @@ void Logger::log(const LevelPtr& level1, const CFStringRef& message) const
 	}
 }
 
-void Logger::warn(const CFStringRef& msg, const log4cxx::spi::LocationInfo& location) const
+void Logger::warn(const CFStringRef& msg, const LOG4CXX_NS::spi::LocationInfo& location) const
 {
 	if (isWarnEnabled())
 	{
-		forcedLog(log4cxx::Level::getWarn(), msg, location);
+		forcedLog(LOG4CXX_NS::Level::getWarn(), msg, location);
 	}
 }
 
@@ -1151,7 +1208,7 @@ void Logger::warn(const CFStringRef& msg) const
 {
 	if (isWarnEnabled())
 	{
-		forcedLog(log4cxx::Level::getWarn(), msg);
+		forcedLog(LOG4CXX_NS::Level::getWarn(), msg);
 	}
 }
 
